import {
  select,
  schemeCategory10,
  csvParse,
  min,
  max,
  extent,
  group,
  flatGroup,
  rollup,
  flatRollup,
  sum,
  bin,
  timeFormat,
} from 'd3';
import { lineChart } from './lineChart';

export const viz = (
  container,
  { state, setState }
) => {
  const width = window.innerWidth;
  const height = window.innerHeight;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  // state.data could be:
  // * undefined
  // * 'LOADING'
  // * An array of objects
  const { data } = state;

  if (data && data !== 'LOADING') {
    svg.call(lineChart, {
      data,
      width,
      height,
      xValue: (d) => d.k,
      yValue: (d) => d.v,
      xAxisLabel: 'Year',
      yAxisLabel: '# of artworks',
      margin: {
        top: 10,
        right: 10,
        bottom: 50,
        left: 50,
      },
      circleRadius: 1,
    });
  }

  if (data === undefined) {
    setState((state) => ({
      ...state,
      data: 'LOADING',
    }));

    fetch('data.csv')
      .then((response) => response.text())
      .then((csvString) => {
        const data = csvParse(csvString);
        var parseTime = d3.timeParse('%Y');
        for (const d of data) {
          d.Date = parseTime(
            d.Date.split('-')[0]
          );
        }
        const year = flatGroup(
          data,
          (d) => d.Date
        );
        let newData = [];
        for (let i = 0; i < year.length; i++) {
          if (year[i][0] != null) {
            newData.push({
              k: year[i][0],
              v: year[i][1].length,
            });
          }
        }
        const summary = newData.sort((a, b) =>
          d3.ascending(a.k, b.k)
        );
        console.log(summary);
        setState((state) => ({
          ...state,
          data: summary,
        }));
      });
  }
};
